Revision History
================

v0.3.1
------
- Rename to pykooh

v0.3.0
------
- Rename to pykoom
- Add support for numba
- Make cython an optonal dependency

v0.2.5
------
- Packaging is hard. MANIFEST is fixed now.

v0.2.4
------
- Added History to MANIFEST.

v0.2.3
------
-  Updated badges.
-  Added tests for example and implemenation notebooks.

v0.2.2
------

-  Moved Cython to a setup_requires

v0.2.1
------

-  Fixed packaging issue

v0.2
----

-  Added calculation of effective amplitude spectrum

v0.1.2
------

-  Initial release
